==> rvm_1.0.tar.gz: rvm-1.0/test-rconfig-051.cc <==
#include "config.h"

#include <iostream>
#include <string>
#include <cassert>

#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

#include <errno.h>

#include "asserts.h"
#include "types.h"
#include "error.h"
#include "estring.h"
#include "fs.h"
#include "tstamp.h"
#include "rconfig.h"
#include "test-rconfig-setup.h"

#define ERR_OUT(e) std::cerr << e;
// #define ERR_OUT(e)

void test(void)
{
	char *argv[256] = { 0 };
	int argc = 0;
	// bool thrown = false;

	argv[argc++] = "<program>";
	argv[argc++] = "--archive";

	config.default_file("./test-rconfig.dir/global-vault-2.dir/file-1.conf");
	config.default_logdir("./test-rconfig.dir/log.dir");
	std::cerr << std::endl;
	std::cerr << "  You should see an error message here:" << std::endl;
	std::cerr << "-----------------------------------------" << std::endl;
	try {
		config.init(argc, argv);
	}
	catch(error e) {
		ERR_OUT(e);
		assert(0);
		// thrown = true;
	}
	catch(...) {
		assert(0);
	}
	std::cerr << "-----------------------------------------" << std::endl;
	std::cerr << std::endl;
	// assert(thrown);
	assert(config.vaults().size() == 3);
	assert(config.vaults()[0] 
		== "./test-rconfig.dir/global-vault-2.dir/vaults/1");
	assert(config.vaults()[1] 
		== "./test-rconfig.dir/global-vault-2.dir/vaults/3");
	assert(config.vaults()[2] 
		== "./test-rconfig.dir/global-vault-2.dir/vaults/4");
}

int main(int argc, char *argv[])
{
	cleanup();
	setup();
	try {
		test();
	}
	catch(error e) {
		std::cerr << e;
		assert(0);
	}
	catch(...) {
		std::cerr << err_unknown;
		assert(0);
	}
	cleanup();
	return(0);
}

==> rvm_1.11.tar.gz: rvm-1.11/test-rconfig-051.cc <==
#include "config.h"

#include <iostream>
#include <string>
#include <cassert>

#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

#include <errno.h>

#include "asserts.h"
#include "types.h"
#include "error.h"
#include "estring.h"
#include "fs.h"
#include "tstamp.h"
#include "rconfig.h"
#include "test-rconfig-setup.h"

#define ERR_OUT(e) std::cerr << e;
// #define ERR_OUT(e)

void test(void)
{
	char const * argv[256] = { 0 };
	int argc = 0;
	// bool thrown = false;

	argv[argc++] = "<program>";
	argv[argc++] = "--archive";

	config.default_file("./test-rconfig.dir/global-vault-2.dir/file-1.conf");
	config.default_logdir("./test-rconfig.dir/log.dir");
	std::cerr << std::endl;
	std::cerr << "  You should see an error message here:" << std::endl;
	std::cerr << "-----------------------------------------" << std::endl;
	try {
		config.init(argc, argv);
	}
	catch(error e) {
		ERR_OUT(e);
		assert(0);
		// thrown = true;
	}
	catch(...) {
		assert(0);
	}
	std::cerr << "-----------------------------------------" << std::endl;
	std::cerr << std::endl;
	// assert(thrown);
	assert(config.vaults().size() == 3);
	assert(config.vaults()[0] 
		== "./test-rconfig.dir/global-vault-2.dir/vaults/1");
	assert(config.vaults()[1] 
		== "./test-rconfig.dir/global-vault-2.dir/vaults/3");
	assert(config.vaults()[2] 
		== "./test-rconfig.dir/global-vault-2.dir/vaults/4");
}

int main(int argc, char const * argv[])
{
	cleanup();
	setup();
	try {
		test();
	}
	catch(error e) {
		std::cerr << e;
		assert(0);
	}
	catch(...) {
		std::cerr << err_unknown;
		assert(0);
	}
	cleanup();
	return(0);
}
